@@ -157,60 +157,70 @@ class LogcatMonitor:
         print("####### STRAT LOGCAT WRITE #######")
         logcat_file_name = "%s%slogcat.txt" % (self._self_folder, os.sep)
         line_count = 0
-        with open(logcat_file_name, 'w', encoding='utf-8') as log_file:
-            while not self._stop_logcat:
-                print("Get logcat")
-                # Keep reading data
-                with self._logcat() as sub:
-                    for line in sub.stdout:
-                        # Whether stop reading logcat
-                        if self._stop_logcat:
-                            # Normal termination
-                            # Stop
-                            print("####### STOP LOGCAT #######")
-                            break
-                        line_count = line_count + 1
-                        # if line_count % 100 == 0:
-                        #     print("####### Line:%d #######" % line_count)
-                        try:
-                            line_str = line.decode("utf-8")
-                        except Exception as ex:
-                            print(ex)
-                            line_str = str(ex)
-                        if self._save_logcat:
-                            log_file.write(line_str)
-                        if not intercept:
-                            # Read data normally
-                            for key in keys:
-                                if line_str.find(key) != -1:
-                                    message = "Detected：%s\n" % key
-                                    print(message)
-                                    self._logs.clear()
-                                    intercept = True
-                                    self._logs.append(line_str)
-                                    rows = 1
-                                    find_key = key
-                        else:
-                            # An error has been detected.
-                            # Read the subsequent qualified logs
-                            if rows < self._rows:
-                                # Add the current line to the logs
+        log_file = None
+
+        # Open logcat file
+        if self._save_logcat:
+            log_file = open(logcat_file_name, 'w+', encoding='utf-8')
+
+        while not self._stop_logcat:
+            print("Get logcat")
+            # Keep reading data
+            with self._logcat() as sub:
+                for line in sub.stdout:
+                    # Whether stop reading logcat
+                    if self._stop_logcat:
+                        # Normal termination
+                        # Stop
+                        print("####### STOP LOGCAT #######")
+                        break
+                    line_count = line_count + 1
+                    try:
+                        line_str = line.decode(encoding="utf-8", errors="ignore")
+                    except Exception as ex:
+                        print(ex)
+                        line_str = str(ex)
+                    # Write logcat file
+                    if log_file is not None:
+                        log_file.write(line_str)
+                    if not intercept:
+                        # Read data normally
+                        for key in keys:
+                            if line_str.find(key) != -1:
+                                message = "Detected：%s\n" % key
+                                print(message)
+                                self._logs.clear()
+                                intercept = True
                                 self._logs.append(line_str)
-                                rows = rows + 1
-                            else:
-                                # Finished reading the required logs
-                                intercept = False
-                                rows = 0
-                                # Increase error counter
-                                self._statistics.increase(self._key_dict, find_key)
-                                # Save as a file
-                                self._save_file(find_key, self._logs)
-                    print("End monitor _logcat")
-                    sub.kill()
-                    if not self._stop_logcat:
-                        # Abnormal termination
-                        # wait...
-                        time.sleep(2)
+                                rows = 1
+                                find_key = key
+                    else:
+                        # An error has been detected.
+                        # Read the subsequent qualified logs
+                        if rows < self._rows:
+                            # Add the current line to the logs
+                            self._logs.append(line_str)
+                            rows = rows + 1
+                        else:
+                            # Finished reading the required logs
+                            intercept = False
+                            rows = 0
+                            # Increase error counter
+                            self._statistics.increase(self._key_dict, find_key)
+                            # Save as a file
+                            self._save_file(find_key, self._logs)
+
+                print("End monitor _logcat")
+                sub.kill()
+                # Close logcat file
+                if log_file is not None:
+                    log_file.close()
+
+                if not self._stop_logcat:
+                    # Abnormal termination
+                    # wait...
+                    time.sleep(2)
+
         print("####### END LOGCAT WRITE #######")
 
     def _logcat_clear(self):
